==> Math-BigInt-1.999838.tar.gz: Math-BigInt-1.999838/README.md <==
# Math-BigInt

Math::BigInt and Math::BigFloat are modules for arbitrary precision
arithmetic.

# INSTALLATION

To install this module, unpack the distribution file, and run the following
commands:

    perl Makefile.PL
    make
    make test
    make install

# SUPPORT AND DOCUMENTATION

After installing, you can find documentation for these modules with the
perldoc command.

    perldoc Math::BigInt
    perldoc Math::BigFloat

You can find documentation for this module with the perldoc command.

    perldoc Math::BigInt

You can also look for information at:

- GitHub

    [https://github.com/pjacklam/p5-Math-BigInt](https://github.com/pjacklam/p5-Math-BigInt)

- RT: CPAN's request tracker

    [https://rt.cpan.org/Dist/Display.html?Name=Math-BigInt](https://rt.cpan.org/Dist/Display.html?Name=Math-BigInt)

- MetaCPAN

    [https://metacpan.org/release/Math-BigInt](https://metacpan.org/release/Math-BigInt)

- CPAN Testers Matrix

    [http://matrix.cpantesters.org/?dist=Math-BigInt](http://matrix.cpantesters.org/?dist=Math-BigInt)

- CPAN Ratings

    [https://cpanratings.perl.org/dist/Math-BigInt](https://cpanratings.perl.org/dist/Math-BigInt)

- The Bignum mailing list
    - Post to mailing list

        `bignum at lists.scsys.co.uk`

    - View mailing list

        [http://lists.scsys.co.uk/pipermail/bignum/](http://lists.scsys.co.uk/pipermail/bignum/)

    - Subscribe/Unsubscribe

        [http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/bignum](http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/bignum)

# COPYRIGHT

Copyright 1996-2001 Mark Biggar, Ilya Zakharevich.

Copyright 2001-2008 Tels, http://bloodgate.com.

Copyright 2010 Florian Ragwitz, flora@cpan.org.

Copyright 2011- Peter John Acklam, pjacklam@gmail.com.

# LICENSE

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

==> Math-BigInt-2.000000.tar.gz: Math-BigInt-2.000000/README.md <==
# Math-BigInt

Math::BigInt, Math::BigFloat, and Math::BigRat are modules for arbitrary
precision integers, floating point numbers, and rational numbers.

# INSTALLATION

To install this module, unpack the distribution file, and run the following
commands:

    perl Makefile.PL
    make
    make test
    make install

# SUPPORT AND DOCUMENTATION

After installing, you can find documentation for these modules with the
perldoc command:

    perldoc Math::BigInt
    perldoc Math::BigFloat
    perldoc Math::BigRat

You can find documentation for the backend libraries with the following
commands:

    perldoc Math::BigInt::Lib
    perldoc Math::BigInt::Calc

You can also look for information at:

- GitHub

    [https://github.com/pjacklam/p5-Math-BigInt](https://github.com/pjacklam/p5-Math-BigInt)

- RT: CPAN's request tracker

    [https://rt.cpan.org/Dist/Display.html?Name=Math-BigInt](https://rt.cpan.org/Dist/Display.html?Name=Math-BigInt)

- MetaCPAN

    [https://metacpan.org/release/Math-BigInt](https://metacpan.org/release/Math-BigInt)

- CPAN Testers Matrix

    [http://matrix.cpantesters.org/?dist=Math-BigInt](http://matrix.cpantesters.org/?dist=Math-BigInt)

# COPYRIGHT

Copyright 1996-2001 Mark Biggar, Ilya Zakharevich.

Copyright 2001-2008 Tels, http://bloodgate.com.

Copyright 2010 Florian Ragwitz, flora@cpan.org.

Copyright 2011- Peter John Acklam, pjacklam@gmail.com.

# LICENSE

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.
